.. include:: ../../README.rst

Contents
========

.. toctree::
   :maxdepth: 2

   userguide
   team


Useful Links
============

- `Quik @ PyPI <https://pypi.python.org/pypi/quik>`_
- `Quik @ Github <https://github.com/avelino/quik>`_


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
